# Licenses
Below are described which licenses apply to the deltalake package and to which areas of the source code.

### deltalake_license.txt (APACHE 2.0 License)
Applies to the full deltalake package source code.

### polars_license.txt (MIT License)
Applies solely to the `_convert_pa_schema_to_delta` function in `deltalake/schema.py`.